==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/federatedfilesharing/l10n/da.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du at tilføje det eksterne drev  {name} fra {owner}@{remote}?",
    "Remote share" : "Eksterne drev",
    "Remote share password" : "Fjerndrev adgangskode",
    "Cancel" : "Annuller",
    "Add remote share" : "Tilføj ekstern deling",
    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server til serverdeling er ikke slået til på denne server",
    "Couldn't establish a federated share." : "Kunne ikke skabe forbindelse til føderal deling ",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunne ikke skabe forbindelse til føderal deling, måske var passwordet forkert.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Føderal deling anmodning sendt, du vil modtage en invitation. Tjek dine notifikationer.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kunne ikke skabe forbindelse til føderal deling, det ser ud til at føderal serveren er for gammel (Nextcloud <=9).",
    "It is not allowed to send federated group shares from this server." : "Det er ikke tilladt at sende fødererede gruppeshares fra denne server.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Deling af %1$s mislykkedes, fordi dette element allerede er delt med bruger%2$s",
    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
    "Federated shares require read permissions" : "Fødererede shares kræver læsetilladelser",
    "File is already shared with %s" : "Filen deles allerede med %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Deling af %1$s mislykkedes, kunne ikke finde %2$s, måske er serveren i øjeblikket ikke tilgængelig eller bruger et selvsigneret certifikat.",
    "Could not find share" : "Kan ikke finde deling",
    "Federated sharing" : "Datafællesskabsdeling",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du modtog {share} som en ekstern deling fra {user} (på vegne af {behalf})",
    "You received {share} as a remote share from {user}" : "Du modtog {share} som en ekstern deling fra {user}",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "Sharing" : "Deling",
    "Federated file sharing" : "Fødereret fildeling",
    "Provide federated file sharing across servers" : "Giv fødereret fildeling på tværs af servere",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Juster, hvordan folk kan dele mellem servere. Dette inkluderer også delinger mellem brugere på denne server, hvis de bruger fødereret deling.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillad brugere på denne server at sende shares til andre servere (denne mulighed giver også WebDAV adgang til offentlige shares)",
    "Allow users on this server to receive shares from other servers" : "Tillad brugere på denne server, at modtage delinger fra andre servere",
    "Allow users on this server to send shares to groups on other servers" : "Tillad brugere på denne server at sende delinger til grupper på andre servere",
    "Allow users on this server to receive group shares from other servers" : "Tillad brugere på denne server at modtage gruppedelinger fra andre servere",
    "Search global and public address book for users" : "Søg global og offentlig adresse bog for brugere",
    "Allow users to publish their data to a global and public address book" : "Tillad brugere at offentliggøre deres data til en global adressebog ",
    "Unable to update federated files sharing config" : "Kan ikke opdatere fødereret fildelingskonfiguration",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dele med alle, der bruger en Nextcloud-server eller andre Open Cloud Mesh (OCM)-kompatible servere og tjenester! Indsæt blot deres Federated Cloud ID i delingsdialogen. Det ligner person@cloud.example.com",
    "Your Federated Cloud ID:" : "Din Federated Cloud ID:",
    "Share it so your friends can share files with you:" : "Del så dine venner kan dele filer med dig:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Tilføj til dit websted",
    "Share with me via Nextcloud" : "Del med mig gennem Nextcloud",
    "HTML Code:" : "HTMLkode:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Del med mig gennem min #Nextcloud Federated Cloud ID, se {url]",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Del med mig gennem min #Nextcloud Federated Cloud ID",
    "Cloud ID copied to the clipboard" : "Cloud ID er kopieret til udklipsholderen.",
    "Copy to clipboard" : "Kopier til udklipsholder",
    "Clipboard is not available" : "Udklipsholderen er ikke tilgængelig",
    "Copied!" : "Kopieret!"
},
"nplurals=2; plural=(n != 1);");

==> php83-nextcloud-30.0.2.tgz: share/nextcloud/apps/federatedfilesharing/l10n/da.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server til serverdeling er ikke slået til på denne server",
    "Couldn't establish a federated share." : "Kunne ikke skabe forbindelse til føderal deling ",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunne ikke skabe forbindelse til føderal deling, måske var passwordet forkert.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Føderal deling anmodning sendt, du vil modtage en invitation. Tjek dine notifikationer.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kunne ikke skabe forbindelse til føderal deling, det ser ud til at føderal serveren er for gammel (Nextcloud <=9).",
    "It is not allowed to send federated group shares from this server." : "Det er ikke tilladt at sende fødererede gruppeshares fra denne server.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Deling af %1$s mislykkedes, fordi dette element allerede er delt med konto %2$s",
    "Not allowed to create a federated share to the same account" : "Ikke tilladt at oprette en fødereret share til den samme konto",
    "Federated shares require read permissions" : "Fødererede shares kræver læsetilladelser",
    "File is already shared with %s" : "Filen deles allerede med %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Deling af %1$s mislykkedes, kunne ikke finde %2$s, måske er serveren i øjeblikket ikke tilgængelig eller bruger et selvsigneret certifikat.",
    "Could not find share" : "Kan ikke finde deling",
    "Federated sharing" : "Datafællesskabsdeling",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du modtog {share} som en ekstern deling fra {user} (på vegne af {behalf})",
    "You received {share} as a remote share from {user}" : "Du modtog {share} som en ekstern deling fra {user}",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "Sharing" : "Deling",
    "Federated file sharing" : "Fødereret fildeling",
    "Provide federated file sharing across servers" : "Giv fødereret fildeling på tværs af servere",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Juster, hvordan brugere kan dele mellem servere. Dette inkluderer også delinger mellem brugere på denne server, hvis de bruger fødereret deling.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillad brugere på denne server at sende shares til andre servere (denne mulighed giver også WebDAV adgang til offentlige shares)",
    "Allow people on this server to receive shares from other servers" : "Tillad brugere på denne server at modtage delinger fra andre servere",
    "Allow people on this server to send shares to groups on other servers" : "Tillad brugere på denne server at sende delinger til grupper på andre servere",
    "Allow people on this server to receive group shares from other servers" : "Tillad brugere på denne server at modtage gruppedelinger fra andre servere",
    "Search global and public address book for people" : "Søg global og offentlig adressebog efter personer",
    "Allow people to publish their data to a global and public address book" : "Tillad brugere at udgive deres data til en global og offentlig adressebog",
    "Unable to update federated files sharing config" : "Kan ikke opdatere fødereret fildelingskonfiguration",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dele med alle, der bruger en Nextcloud-server eller andre Open Cloud Mesh (OCM)-kompatible servere og tjenester! Indsæt blot deres Federated Cloud ID i delingsdialogen. Det ligner person@cloud.example.com",
    "Share it so your friends can share files with you:" : "Del så dine venner kan dele filer med dig:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (tidligere Twitter)",
    "formerly Twitter" : "tidligere Twitter",
    "Mastodon" : "Mastodont",
    "Add to your website" : "Tilføj til dit websted",
    "Share with me via Nextcloud" : "Del med mig gennem Nextcloud",
    "HTML Code:" : "HTMLkode:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Del med mig gennem min #Nextcloud Federated Cloud ID, se {url]",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Del med mig gennem min #Nextcloud Federated Cloud ID",
    "Cloud ID copied to the clipboard" : "Cloud ID er kopieret til udklipsholderen.",
    "Copy to clipboard" : "Kopier til udklipsholder",
    "Clipboard not available. Please copy the cloud ID manually." : "Udklipsholder ikke tilgængelig. Kopier venligst Cloud ID'et manuelt.",
    "Copied!" : "Kopieret!",
    "Cancel" : "Annuller",
    "Add remote share" : "Tilføj ekstern deling",
    "Remote share" : "Eksterne drev",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du at tilføje det eksterne drev  {name} fra {owner}@{remote}?",
    "Remote share password" : "Fjerndrev adgangskode",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Deling af %1$s mislykkedes, fordi dette element allerede er delt med bruger%2$s",
    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Juster, hvordan folk kan dele mellem servere. Dette inkluderer også delinger mellem brugere på denne server, hvis de bruger fødereret deling.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillad brugere på denne server at sende shares til andre servere (denne mulighed giver også WebDAV adgang til offentlige shares)",
    "Allow users on this server to receive shares from other servers" : "Tillad brugere på denne server, at modtage delinger fra andre servere",
    "Allow users on this server to send shares to groups on other servers" : "Tillad brugere på denne server at sende delinger til grupper på andre servere",
    "Allow users on this server to receive group shares from other servers" : "Tillad brugere på denne server at modtage gruppedelinger fra andre servere",
    "Search global and public address book for users" : "Søg global og offentlig adresse bog for brugere",
    "Allow users to publish their data to a global and public address book" : "Tillad brugere at offentliggøre deres data til en global adressebog ",
    "Your Federated Cloud ID:" : "Din Federated Cloud ID:",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "Udklipsholderen er ikke tilgængelig"
},
"nplurals=2; plural=(n != 1);");
